@@ -1,8 +1,9 @@
+
 from paramak import RotateStraightShape
 
 
 class PoloidalFieldCoilCase(RotateStraightShape):
-    """Creates a casing for a reactangular coil from inputs that
+    """Creates a casing for a rectangular coil from inputs that
     describe the existing coil and the thickness of the casing required.
 
     Args:
@@ -12,35 +13,9 @@ class PoloidalFieldCoilCase(RotateStraightShape):
             (cm).
         casing_thickness (tuple of floats): the thickness of the coil casing
             (cm).
-
-    Keyword Args:
-        name (str): the legend name used when exporting a html graph of the
-            shape.
-        color (sequences of 3 or 4 floats each in the range 0-1): the color to
-            use when exporting as html graphs or png images.
-        material_tag (str): The material name to use when exporting the
-            neutronics description.
-        stp_filename (str): The filename used when saving stp files as part of a
-            reactor.
-        azimuth_placement_angle (float or iterable of floats): The angle or
-            angles to use when rotating the shape on the azimuthal axis.
-        rotation_angle (float): The rotation angle to use when revolving the
-            solid (degrees).
-        workplane (str): The orientation of the CadQuery workplane. Options are
-            XY, YZ or XZ.
-        intersect (CadQuery object): An optional CadQuery object to perform a
-            boolean intersect with this object.
-        cut (CadQuery object): An optional CadQuery object to perform a boolean
-            cut with this object.
-        union (CadQuery object): An optional CadQuery object to perform a
-            boolean union with this object.
-        tet_mesh (str): Insert description.
-        physical_groups (type): Insert description.
-
-    Returns:
-        a paramak shape object: A shape object that has generic functionality
-        with points determined by the find_points() method. A CadQuery solid of
-        the shape can be called via shape.solid.
+        stp_filename (str, optional): defaults to "PoloidalFieldCoilCase.stp".
+        stl_filename (str, optional): defaults to "PoloidalFieldCoilCase.stl".
+        material_tag (str, optional): defaults to "pf_coil_case_mat".
     """
 
     def __init__(
@@ -49,41 +24,17 @@ class PoloidalFieldCoilCase(RotateStraightShape):
         coil_height,
         coil_width,
         center_point,
-        rotation_angle=360,
         stp_filename="PoloidalFieldCoilCase.stp",
         stl_filename="PoloidalFieldCoilCase.stl",
-        color=(0.5, 0.5, 0.5),
-        azimuth_placement_angle=0,
-        name=None,
         material_tag="pf_coil_case_mat",
         **kwargs
     ):
 
-        default_dict = {
-            "points": None,
-            "workplane": "XZ",
-            "solid": None,
-            "intersect": None,
-            "cut": None,
-            "union": None,
-            "tet_mesh": None,
-            "physical_groups": None,
-        }
-
-        for arg in kwargs:
-            if arg in default_dict:
-                default_dict[arg] = kwargs[arg]
-
         super().__init__(
-            name=name,
-            color=color,
             material_tag=material_tag,
             stp_filename=stp_filename,
             stl_filename=stl_filename,
-            azimuth_placement_angle=azimuth_placement_angle,
-            rotation_angle=rotation_angle,
-            hash_value=None,
-            **default_dict
+            **kwargs
         )
 
         self.center_point = center_point
